# Read in datafiles (inc. check)
dat<-read.csv("I:\\PhD work\\Amphibian diversification study\\Analysis files\\totdat.csv",header=T,row.names=1)
dat$cd<-as.factor(dat$cd)
dat$con0<-as.factor(dat$con0)
dat$con1<-as.factor(dat$con1)
summary(dat)
dat[1:10,]
condat<-read.csv("I:\\PhD work\\Amphibian diversification study\\Analysis files\\condat.csv",header=T,row.names=1)
condat$cd<-as.factor(condat$cd)
condat$con0<-as.factor(condat$con0)
condat$con1<-as.factor(condat$con1)
summary(condat)
condat[1:10,]
cddat<-read.csv("I:\\PhD work\\Amphibian diversification study\\Analysis files\\cddat.csv",header=T,row.names=1)
cddat$cd<-as.factor(cddat$cd)
cddat$con0<-as.factor(cddat$con0)
cddat$con1<-as.factor(cddat$con1)
summary(cddat)
cddat[1:10,]

# Open and check reduced trees
library(ape)
tree<-read.tree("I:\\PhD work\\Amphibian diversification study\\Analysis files\\amphibia.nwk")
summary(tree)
is.ultrametric(tree)
contree<-read.tree("I:\\PhD work\\Amphibian diversification study\\Analysis files\\contree.nwk")
summary(contree)
is.ultrametric(contree)
cdtree<-read.tree("I:\\PhD work\\Amphibian diversification study\\Analysis files\\cdtree.nwk")
summary(cdtree)
is.ultrametric(cdtree)

# View trees
plot(tree,show.tip.label=F,no.margin=T,edge.color="dark blue")
plot(contree,show.tip.label=F,no.margin=T,edge.color="dark blue")
plot(cdtree,show.tip.label=F,no.margin=T,edge.color="dark blue")

# Extracting sister group data for the following method
library(phangorn)
sister.extract<-function(tree,x){
intNodes=(Ntip(tree)+1L):(Ntip(tree)+Nnode(tree))
sisters=Children(tree,intNodes)
sisters=matrix(unlist(sisters),byrow=TRUE,ncol=2,dimnames=list(intNodes,NULL))
desc=Descendants(tree)
x=(x=="1")
l=sapply(desc,length)
yes=sapply(desc,function(d,x)sum(x[d]),x)
no=(l-yes)
allno=(no==l)
allyes=(yes==l)
res=rbind(cbind(no[sisters[,1]],yes[sisters[,2]])[allno[sisters[,1]]&allyes[sisters[,2]],],cbind(no[sisters[,2]],yes[sisters[,1]])[allno[sisters[,2]]&allyes[sisters[,1]],])
res=as.data.frame(res)
colnames(res)<-c("with","without")
return(res)
}

# Richness Yule test
library(ape)
cdsis<-sister.extract(cdtree,cddat$cd)
intNodes=(Ntip(cdtree)+1L):(Ntip(cdtree)+Nnode(cdtree))
sisters=Children(cdtree,intNodes)
sisters=matrix(unlist(sisters),byrow=TRUE,ncol=2,dimnames=list(intNodes,NULL))
desc=Descendants(cdtree)
x=(cddat$cd=="1")
l=sapply(desc,length)
yes=sapply(desc,function(d,x)sum(x[d]),x)
no=(l-yes)
allno=(no==l)
allyes=(yes==l)
cdsisnodes<-c(rownames(sisters)[allno[sisters[,1]]&allyes[sisters[,2]]],rownames(sisters)[allno[sisters[,2]]&allyes[sisters[,1]]])
cdsisdivtim<-as.numeric(cdtree$node.label[as.numeric(cdsisnodes)-Ntip(cdtree)])
richness.yule.test(cdsis,cdsisdivtim)
con0sis<-sister.extract(contree,condat$con0)
intNodes=(Ntip(contree)+1L):(Ntip(contree)+Nnode(contree))
sisters=Children(contree,intNodes)
sisters=matrix(unlist(sisters),byrow=TRUE,ncol=2,dimnames=list(intNodes,NULL))
desc=Descendants(contree)
x=(condat$con0=="1")
l=sapply(desc,length)
yes=sapply(desc,function(d,x)sum(x[d]),x)
no=(l-yes)
allno=(no==l)
allyes=(yes==l)
con0sisnodes<-c(rownames(sisters)[allno[sisters[,1]]&allyes[sisters[,2]]],rownames(sisters)[allno[sisters[,2]]&allyes[sisters[,1]]])
con0sisdivtim<-as.numeric(contree$node.label[as.numeric(con0sisnodes)-Ntip(contree)])
richness.yule.test(con0sis,con0sisdivtim)
con1sis<-sister.extract(contree,condat$con1)
intNodes=(Ntip(contree)+1L):(Ntip(contree)+Nnode(contree))
sisters=Children(contree,intNodes)
sisters=matrix(unlist(sisters),byrow=TRUE,ncol=2,dimnames=list(intNodes,NULL))
desc=Descendants(contree)
x=(condat$con1=="1")
l=sapply(desc,length)
yes=sapply(desc,function(d,x)sum(x[d]),x)
no=(l-yes)
allno=(no==l)
allyes=(yes==l)
con1sisnodes<-c(rownames(sisters)[allno[sisters[,1]]&allyes[sisters[,2]]],rownames(sisters)[allno[sisters[,2]]&allyes[sisters[,1]]])
con1sisdivtim<-as.numeric(contree$node.label[as.numeric(con1sisnodes)-Ntip(contree)])
richness.yule.test(con1sis,con1sisdivtim)

# Simulating random traits and testing BiSSE model for chemical defence
# System time for one run (from 'trait<-' to 'fit<-') based on cd data is 1.98 mins
library(diversitree)
library(MuMIn)
phy<-cdtree
ranlik<-c()
ranaic<-c()
pbi<-winProgressBar(title="BiSSE setup",label="0% done",min=0,max=100,initial=0)
pbf<-winProgressBar(title="BiSSE model fit",label="0% done",min=0,max=100,initial=0)
for (i in 1:100){
info<-sprintf("%d%% done", round((i/100)*100))
trait<-sample(c(rep(0,times=302),rep(1,times=555)))
names(trait)<-phy$tip.label
lik<-make.bisse(phy,trait,sampling.f=c(0.11,0.11))
start<-starting.point.bisse(phy)
setWinProgressBar(pbi,round((i/100)*100),label=info)
fit<-find.mle(lik,start)
setWinProgressBar(pbf,round((i/100)*100),label=info)
ranlik[i]<-logLik(fit)
ranaic[i]<-AIC(fit)
}
aic<-c(full=8592.83,null=8623.05,eqdiv=8602.95,eqsp=8604.93,eqex=8604.53,minran=min(ranaic),maxran=max(ranaic))
delta<-aic-min(aic)
w<-Weights(aic)
er<-w[1]/w
min(ranlik)
max(ranlik)
aic
delta
round(w,digits=3)
er
cdout<-data.frame(loglik=ranlik,aic=ranaic)
write.csv(cdout,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\rTraitDistcd.csv")

# ASR under the best BiSSE model for chemical defence
library(diversitree)
library(phytools)
tox<-as.numeric(cddat$cd)-1
names(tox)<-rownames(cddat)
lik<-make.bisse(cdtree,tox,sampling.f=c(0.11,0.11))
asr<-asr.marginal(lik,pars=c(0.141240475,0.28359524,0.084599443,0.263155028,0.02265158,0.001014864))
plotBranchbyTrait(cdtree,asr[2,],show.tip.label=F,no.margin=T,edge.width=1,prompt=T,type="fan")

# ASR under the best BiSSE models for colouration
par(mfrow=c(1,2))
col<-as.numeric(condat$con0)-1
names(col)<-rownames(condat)
lik<-make.bisse(contree,col,sampling.f=c(0.34,0.33))
lik.excon<-constrain(lik,mu1~mu0)
asr<-asr.marginal(lik.excon,pars=c(0.059198612,0.18177177,0.023908397,0.001544873,0.147260796))
plotBranchbyTrait(contree,asr[2,],show.tip.label=F,no.margin=T,edge.width=1,prompt=T,type="fan")
col<-as.numeric(condat$con1)-1
names(col)<-rownames(condat)
lik<-make.bisse(contree,col,sampling.f=c(0.34,0.33))
asr<-asr.marginal(lik,pars=c(0.06118987,0.09847387,0.00000108594,0.0811571,0.003994628,0.004364655))
plotBranchbyTrait(contree,asr[2,],show.tip.label=F,no.margin=T,edge.width=1,prompt=T,type="fan")

