# Open and check full tree
library(ape)
tree<-read.tree("F:\\PhD work\\Amphibian diversification study\\Analysis files\\amphibia.nwk")
summary(tree)
is.ultrametric(tree)

# View tree
plot(tree,show.tip.label=F,no.margin=T,edge.color="dark blue")

# Generate datafile to allow data entry (inc. check)
dat<-data.frame(bin=c(1:length(tree$tip.label)),row.names=tree$tip.label)
namevector<-c("con","cd","con0","con1")
dat[,namevector]<-""
dat[1:10,]
write.csv(dat,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\totdat.csv")

# Create reduced dataframe and tree for con data (inc. check)
condat<-subset(dat,con!="NA",select=c(bin,con,cd,con0,con1))
condat[1:10,]
summary(condat)
write.csv(condat,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\condat.csv")

# Create reduced dataframe and tree for cd data (inc. check)
cddat<-subset(dat,cd!="NA",select=c(bin,con,cd,con0,con1))
cddat[1:10,]
summary(cddat)
write.csv(cddat,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\cddat.csv")

# Read in datafiles (inc. check)
dat<-read.csv("F:\\PhD work\\Amphibian diversification study\\Analysis files\\totdat.csv",header=T,row.names=1)
dat$cd<-as.factor(dat$cd)
dat$con0<-as.factor(dat$con0)
dat$con1<-as.factor(dat$con1)
summary(dat)
dat[1:10,]

condat<-read.csv("F:\\PhD work\\Amphibian diversification study\\Analysis files\\condat.csv",header=T,row.names=1)
condat$cd<-as.factor(condat$cd)
condat$con0<-as.factor(condat$con0)
condat$con1<-as.factor(condat$con1)
summary(condat)
condat[1:10,]

cddat<-read.csv("F:\\PhD work\\Amphibian diversification study\\Analysis files\\cddat.csv",header=T,row.names=1)
cddat$cd<-as.factor(cddat$cd)
cddat$con0<-as.factor(cddat$con0)
cddat$con1<-as.factor(cddat$con1)
summary(cddat)
cddat[1:10,]

# Generate reduced tree for con data (inc. check)
conrows<-rownames(dat[which(is.na(dat$con)),])
conrows[1:10]
length(conrows)
contree<-drop.tip(tree,conrows)
summary(contree)
is.ultrametric(contree)
write.tree(contree,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\contree.nwk")

# Generate reduced tree for cd data (inc. check)
cdrows<-rownames(dat[which(is.na(dat$cd)),])
cdrows[1:10]
length(cdrows)
cdtree<-drop.tip(tree,cdrows)
summary(cdtree)
is.ultrametric(cdtree)
write.tree(cdtree,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\cdtree.nwk")

# Open and check reduced trees
library(ape)
contree<-read.tree("F:\\PhD work\\Amphibian diversification study\\Analysis files\\contree.nwk")
summary(contree)
is.ultrametric(contree)

cdtree<-read.tree("F:\\PhD work\\Amphibian diversification study\\Analysis files\\cdtree.nwk")
summary(cdtree)
is.ultrametric(cdtree)

# View reduced trees
plot(contree,show.tip.label=F,no.margin=T,edge.color="dark blue")
plot(cdtree,show.tip.label=F,no.margin=T,edge.color="dark blue")

# GEE to look at whether chemical defence predicts conspicuous coloration
library(ape)
gee0<-compar.gee(con0~cd,data=cddat,family=binomial,phy=cdtree)
gee1<-compar.gee(con1~cd,data=cddat,family=binomial,phy=cdtree)

# Pagel's (1994) test of correlation between chemical defence and conspicuous coloration (con0)
library(corHMM)
cor0<-data.frame(rownames(cddat),cddat$cd,cddat$con0)
ermod<-corDISC(cdtree,cor0,ntraits=2,model="ER")
symmod<-corDISC(cdtree,cor0,ntraits=2,model="SYM")
ardmod<-corDISC(cdtree,cor0,ntraits=2,model="ARD")
# ARD model is preferred for cor0 (deltaAICc ~86 for SYM and ~184 for ER)
cormat<-rate.mat.maker(hrm=FALSE,ntraits=2,model="ARD")
indmat<-rate.par.eq(cormat, eq.par=c(3,8)) #q12=q34
indmat<-rate.par.eq(indmat, eq.par=c(1,6)) #q21=q43
indmat<-rate.par.eq(indmat, eq.par=c(5,6)) #q13=q24
indmat<-rate.par.eq(indmat, eq.par=c(2,4)) #q31=q42
cormod<-corDISC(cdtree,cor0,ntraits=2,rate.mat=cormat,model="ARD")
indmod<-corDISC(cdtree,cor0,ntraits=2,rate.mat=indmat,model="ARD")
# Correlated model is favoured for con0 (positive correlation)

# Pagel's (1994) test of correlation between chemical defence and conspicuous coloration (con1)
library(corHMM)
cor1<-data.frame(rownames(cddat),cddat$cd,cddat$con1)
ermod<-corDISC(cdtree,cor1,ntraits=2,model="ER")
symmod<-corDISC(cdtree,cor1,ntraits=2,model="SYM")
ardmod<-corDISC(cdtree,cor1,ntraits=2,model="ARD")
# ARD model is preferred for cor1 (deltaAICc ~71 for SYM and ~116 for ER)
cormat<-rate.mat.maker(hrm=FALSE,ntraits=2,model="ARD")
indmat<-rate.par.eq(cormat,eq.par=c(3,8)) #q12=q34
indmat<-rate.par.eq(indmat,eq.par=c(1,6)) #q21=q43
indmat<-rate.par.eq(indmat,eq.par=c(5,6)) #q13=q24
indmat<-rate.par.eq(indmat,eq.par=c(2,4)) #q31=q42
cormod<-corDISC(cdtree,cor1,ntraits=2,rate.mat=cormat,model="ARD")
indmod<-corDISC(cdtree,cor1,ntraits=2,rate.mat=indmat,model="ARD")
# Correlated model is favoured for con1 (positive correlation)

# BiSSE analysis of chemical defence data with ML (sampling fraction as observed in the dataset, assuming 7869 currently known species)
library(diversitree)
tox<-as.numeric(cddat$cd)-1
names(tox)<-rownames(cddat)
lik<-make.bisse(cdtree,tox,sampling.f=c(0.11,0.11))
start<-starting.point.bisse(cdtree)
fit<-find.mle(lik,start)
fit
logLik(fit)
AIC(fit)
lik.allcon<-constrain(lik,lambda1~lambda0,mu1~mu0,q01~q10)
fit.allcon<-find.mle(lik.allcon,start[-c(1,3,5)])
fit.allcon
logLik(fit.allcon)
AIC(fit.allcon)
lik.divcon<-constrain(lik,lambda1~lambda0,mu1~mu0)
fit.divcon<-find.mle(lik.divcon,start[-c(1,3)])
fit.divcon
logLik(fit.divcon)
AIC(fit.divcon)
lik.spcon<-constrain(lik,lambda1~lambda0)
fit.spcon<-find.mle(lik.spcon,start[-1])
fit.spcon
logLik(fit.spcon)
AIC(fit.spcon)
lik.excon<-constrain(lik,mu1~mu0)
fit.excon<-find.mle(lik.excon,start[-3])
fit.excon
logLik(fit.excon)
AIC(fit.excon)
aic<-c(AIC(fit),AIC(fit.allcon),AIC(fit.divcon),AIC(fit.spcon),AIC(fit.excon))
library(MuMIn)
delta<-aic-min(aic)
delta
w<-Weights(aic)
round(w,digits=3)
er<-w[1]/w
er

# BiSSE analysis of conspicuous coloration (con0) data with ML (sampling fraction as observed in the dataset, assuming 7869 currently known species)
library(diversitree)
col<-as.numeric(condat$con0)-1
names(col)<-rownames(condat)
lik<-make.bisse(contree,col,sampling.f=c(0.34,0.33))
start<-starting.point.bisse(contree)
fit<-find.mle(lik,start)
fit
logLik(fit)
AIC(fit)
lik.allcon<-constrain(lik,lambda1~lambda0,mu1~mu0,q01~q10)
fit.allcon<-find.mle(lik.allcon,start[-c(1,3,5)])
fit.allcon
logLik(fit.allcon)
AIC(fit.allcon)
lik.divcon<-constrain(lik,lambda1~lambda0,mu1~mu0)
fit.divcon<-find.mle(lik.divcon,start[-c(1,3)])
fit.divcon
logLik(fit.divcon)
AIC(fit.divcon)
lik.spcon<-constrain(lik,lambda1~lambda0)
fit.spcon<-find.mle(lik.spcon,start[-1])
fit.spcon
logLik(fit.spcon)
AIC(fit.spcon)
lik.excon<-constrain(lik,mu1~mu0)
fit.excon<-find.mle(lik.excon,start[-3])
fit.excon
logLik(fit.excon)
AIC(fit.excon)
aic<-c(AIC(fit),AIC(fit.allcon),AIC(fit.divcon),AIC(fit.spcon),AIC(fit.excon))
library(MuMIn)
delta<-aic-min(aic)
delta
w<-Weights(aic)
round(w,digits=3)
er<-w[5]/w
er

# BiSSE analysis of conspicuous coloration (con1) data with ML (sampling fraction as observed in the dataset, assuming 7869 currently known species)
library(diversitree)
col<-as.numeric(condat$con1)-1
names(col)<-rownames(condat)
lik<-make.bisse(contree,col,sampling.f=c(0.34,0.33))
start<-starting.point.bisse(contree)
fit<-find.mle(lik,start)
fit
logLik(fit)
AIC(fit)
lik.allcon<-constrain(lik,lambda1~lambda0,mu1~mu0,q01~q10)
fit.allcon<-find.mle(lik.allcon,start[-c(1,3,5)])
fit.allcon
logLik(fit.allcon)
AIC(fit.allcon)
lik.divcon<-constrain(lik,lambda1~lambda0,mu1~mu0)
fit.divcon<-find.mle(lik.divcon,start[-c(1,3)])
fit.divcon
logLik(fit.divcon)
AIC(fit.divcon)
lik.spcon<-constrain(lik,lambda1~lambda0)
fit.spcon<-find.mle(lik.spcon,start[-1])
fit.spcon
logLik(fit.spcon)
AIC(fit.spcon)
lik.excon<-constrain(lik,mu1~mu0)
fit.excon<-find.mle(lik.excon,start[-3])
fit.excon
logLik(fit.excon)
AIC(fit.excon)
aic<-c(AIC(fit),AIC(fit.allcon),AIC(fit.divcon),AIC(fit.spcon),AIC(fit.excon))
library(MuMIn)
delta<-aic-min(aic)
delta
w<-Weights(aic)
round(w,digits=3)
er<-w[1]/w
er

# BiSSE analysis of chemical defence data with MCMC (sampling fraction as observed in the dataset, assuming 7869 currently known species. Starting parameters from best model in ML analysis)
library(diversitree)
tox<-as.numeric(cddat$cd)-1
names(tox)<-rownames(cddat)
lik<-make.bisse(cdtree,tox,sampling.f=c(0.11,0.11))
start<-c(0.141240475,0.28359524,0.084599443,0.263155028,0.02265158,0.001014864)
tmp<-mcmc(lik,start,nsteps=1000,w=0.1)
w<-diff(sapply(tmp[2:7],quantile,c(.05, .95)))
cdmc<-mcmc(lik,start,nsteps=15000,w=w)
write.csv(cdmc,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\cdpost.csv")
cdpostburn<-cdmc[5001:15000,]
write.csv(cdpostburn,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\cdpostburn.csv")

# Plotting parameter estimates for chemical defence data from MCMC analysis of best ML model
library(diversitree)
par(mfrow=c(2,2))
cdlam<-data.frame(cdpostburn$lambda0,cdpostburn$lambda1)
colnames(cdlam)<-c("No cd","Cd")
profiles.plot(cdlam[c("No cd","Cd")],col.line=c("blue", "red"),las=1,xlab="Speciation rate", legend="topright")
cdmu<-data.frame(cdpostburn$mu0,cdpostburn$mu1)
colnames(cdmu)<-c("No cd","Cd")
profiles.plot(cdmu[c("No cd","Cd")],col.line=c("blue", "red"),las=1,xlab="Extinction rate", legend="topright")
cdq<-data.frame(cdpostburn$q01,cdpostburn$q10)
colnames(cdq)<-c("Gain of cd","Loss of cd")
profiles.plot(cdq[c("Gain of cd","Loss of cd")],col.line=c("red", "blue"),las=1,xlab="Transition rates", legend="topright")
cdpostburn$netdiv0<-cdpostburn$lambda0-cdpostburn$mu0
cdpostburn$netdiv1<-cdpostburn$lambda1-cdpostburn$mu1
cddiv<-data.frame(cdpostburn$netdiv0,cdpostburn$netdiv1)
colnames(cddiv)<-c("No cd","Cd")
profiles.plot(cddiv[c("No cd","Cd")],col.line=c("blue", "red"),las=1,xlab="Net diversification rate (spec. - ex.)", legend="topright")

# BiSSE analysis of conspicuous coloration (con0) data with MCMC (sampling fraction as observed in the dataset, assuming 7869 currently known species. Starting parameters from best model in ML analysis)
library(diversitree)
col<-as.numeric(condat$con0)-1
names(col)<-rownames(condat)
lik<-make.bisse(contree,col,sampling.f=c(0.34,0.33))
lik.excon<-constrain(lik,mu1~mu0)
start<-c(0.059198612,0.18177177,0.023908397,0.001544873,0.147260796)
tmp<-mcmc(lik.excon,start,nsteps=1000,w=0.1)
w<-diff(sapply(tmp[2:6],quantile,c(.05, .95)))
con0mc<-mcmc(lik.excon,start,nsteps=15000,w=w)
write.csv(con0mc,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\con0post.csv")
con0postburn<-con0mc[5001:15000,]
write.csv(con0postburn,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\con0postburn.csv")

# Plotting parameter estimates for conspicuous coloration (con0) data from MCMC analysis of best ML model
library(diversitree)
par(mfrow=c(2,2))
con0lam<-data.frame(con0postburn$lambda0,con0postburn$lambda1)
colnames(con0lam)<-c("Cryptic","Conspic.")
profiles.plot(con0lam[c("Cryptic","Conspic.")],col.line=c("blue", "red"),las=1,xlab="Speciation rate", legend="topright")
profiles.plot(con0postburn["mu0"],col.line=c("purple4"),las=1,xlab="Extinction rate", legend=NULL)
con0q<-data.frame(con0postburn$q01,con0postburn$q10)
colnames(con0q)<-c("Gain of conspic.","Loss of conspic.")
profiles.plot(con0q[c("Gain of conspic.","Loss of conspic.")],col.line=c("red", "blue"),las=1,xlab="Transition rates", legend="topright")
con0postburn$netdiv0<-con0postburn$lambda0-con0postburn$mu0
con0postburn$netdiv1<-con0postburn$lambda1-con0postburn$mu0
con0div<-data.frame(con0postburn$netdiv0,con0postburn$netdiv1)
colnames(con0div)<-c("Cryptic","Conspic.")
profiles.plot(con0div[c("Cryptic","Conspic.")],col.line=c("blue", "red"),las=1,xlab="Net diversification rate (spec. - ex.)", legend="topright")

# BiSSE analysis of conspicuous coloration (con1) data with MCMC (sampling fraction as observed in the dataset, assuming 7869 currently known species. Starting parameters from best model in ML analysis)
library(diversitree)
col<-as.numeric(condat$con1)-1
names(col)<-rownames(condat)
lik<-make.bisse(contree,col,sampling.f=c(0.34,0.33))
start<-c(0.06118987,0.09847387,0.00000108594,0.0811571,0.003994628,0.004364655)
tmp<-mcmc(lik,start,nsteps=1000,w=0.1)
w<-diff(sapply(tmp[2:7],quantile,c(.05, .95)))
con1mc<-mcmc(lik,start,nsteps=15000,w=w)
write.csv(con1mc,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\con1post.csv")
con1postburn<-con1mc[5001:15000,]
write.csv(con1postburn,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\con1postburn.csv")

# Plotting parameter estimates for conspicuous coloration (con1) data from MCMC analysis of best ML model
library(diversitree)
par(mfrow=c(2,2))
con1lam<-data.frame(con1postburn$lambda0,con1postburn$lambda1)
colnames(con1lam)<-c("Cryptic","Conspic.")
profiles.plot(con1lam[c("Cryptic","Conspic.")],col.line=c("blue", "red"),las=1,xlab="Speciation rate", legend="topright")
con1mu<-data.frame(con1postburn$mu0,con1postburn$mu1)
colnames(con1mu)<-c("Cryptic","Conspic.")
profiles.plot(con1mu[c("Cryptic","Conspic.")],col.line=c("blue", "red"),las=1,xlab="Extinction rate", legend="topright")
con1q<-data.frame(con1postburn$q01,con1postburn$q10)
colnames(con1q)<-c("Gain of conspic.","Loss of conspic.")
profiles.plot(con1q[c("Gain of conspic.","Loss of conspic.")],col.line=c("red", "blue"),las=1,xlab="Transition rates", legend="topright")
con1postburn$netdiv0<-con1postburn$lambda0-con1postburn$mu0
con1postburn$netdiv1<-con1postburn$lambda1-con1postburn$mu1
con1div<-data.frame(con1postburn$netdiv0,con1postburn$netdiv1)
colnames(con1div)<-c("Cryptic","Conspic.")
profiles.plot(con1div[c("Cryptic","Conspic.")],col.line=c("blue", "red"),las=1,xlab="Net diversification rate (spec. - ex.)", legend=locator(1))

# MuSSE (multitrait) analysis of conspicuous coloration (con0) and chemical defence data with ML (sampling fraction as proportion of amphibian species present in the analysis, assuming 7869 currently known species)
library(diversitree)
c<-as.numeric(cddat$con0)-1
d<-as.numeric(cddat$cd)-1
musdat<-data.frame(c,d)
rownames(musdat)<-rownames(cddat)
lik<-make.musse.multitrait(cdtree,musdat,sampling.f=0.11)
lik<-constrain(lik,muc~0)
start<-starting.point.musse.multitrait(cdtree,lik)
fit<-find.mle(lik,start)
fit
logLik(fit)
AIC(fit)
lik.div.noint<-constrain(lik,lambdacd~0,mucd~0)
fit.div.noint<-find.mle(lik.div.noint,start[-c(4,7)])
fit.div.noint
logLik(fit.div.noint)
AIC(fit.div.noint)
lik.sp.noint<-constrain(lik,lambdacd~0)
fit.sp.noint<-find.mle(lik.sp.noint,start[-4])
fit.sp.noint
logLik(fit.sp.noint)
AIC(fit.sp.noint)
lik.ex.noint<-constrain(lik,mucd~0)
fit.ex.noint<-find.mle(lik.ex.noint,start[-7])
fit.ex.noint
logLik(fit.ex.noint)
AIC(fit.ex.noint)
aic<-c(AIC(fit),AIC(fit.div.noint),AIC(fit.sp.noint),AIC(fit.ex.noint))
library(MuMIn)
delta<-aic-min(aic)
delta
w<-Weights(aic)
round(w,digits=3)

# MuSSE (multitrait) analysis of conspicuous coloration (con1) and chemical defence data with ML (sampling fraction as proportion of amphibian species present in the analysis, assuming 7869 currently known species)
library(diversitree)
c<-as.numeric(cddat$con1)-1
d<-as.numeric(cddat$cd)-1
musdat<-data.frame(c,d)
rownames(musdat)<-rownames(cddat)
lik<-make.musse.multitrait(cdtree,musdat,sampling.f=0.11)
start<-starting.point.musse.multitrait(cdtree,lik)
fit<-find.mle(lik,start)
fit
logLik(fit)
AIC(fit)
lik.div.noint<-constrain(lik,lambdacd~0,mucd~0)
fit.div.noint<-find.mle(lik.div.noint,start[-c(4,8)])
fit.div.noint
logLik(fit.div.noint)
AIC(fit.div.noint)
lik.sp.noint<-constrain(lik,lambdacd~0)
fit.sp.noint<-find.mle(lik.sp.noint,start[-4])
fit.sp.noint
logLik(fit.sp.noint)
AIC(fit.sp.noint)
lik.ex.noint<-constrain(lik,mucd~0)
fit.ex.noint<-find.mle(lik.ex.noint,start[-8])
fit.ex.noint
logLik(fit.ex.noint)
AIC(fit.ex.noint)
aic<-c(AIC(fit),AIC(fit.div.noint),AIC(fit.sp.noint),AIC(fit.ex.noint))
library(MuMIn)
delta<-aic-min(aic)
delta
w<-Weights(aic)
round(w,digits=3)

# MuSSE (multitrait) analysis of conspicuous coloration (con0) and chemical defence data with MCMC (sampling fraction as proportion of amphibian species present in the analysis, assuming 7869 currently known species)
library(diversitree)
c<-as.numeric(cddat$con0)-1
d<-as.numeric(cddat$cd)-1
musdat<-data.frame(c,d)
rownames(musdat)<-rownames(cddat)
lik<-make.musse.multitrait(cdtree,musdat,sampling.f=0.11)
lik<-constrain(lik,muc~0)
# probably have to add in other constraints to reflect best model
start<-c(0.059198612,0.18177177,0.023908397,0.001544873,0.147260796) # vector of ML estimates from best model
tmp<-mcmc(lik,start,nsteps=1000,w=0.1)
w<-diff(sapply(tmp[2:6],quantile,c(.05, .95))) # check column numbers from tmp
multi0mc<-mcmc(lik,start,nsteps=15000,w=w)
write.csv(multi0mc,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\multi0post.csv")
multi0postburn<-multi0mc[5001:15000,]
write.csv(multi0postburn,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\multi0postburn.csv")

# Plotting parameter estimates for conspicuous coloration (con0) and chemical defence data from MCMC analysis of best ML model
# May need to adjust this to reflect the actual model to be plotted
library(diversitree)
par(mfrow=c(2,2))
multi0lam<-data.frame(multi0postburn$lambdac,multi0postburn$lambdad,multi0postburn$lambdacd)
colnames(multi0lam)<-c("Conspic.","Cd","Interaction")
profiles.plot(multi0lam[c("Conspic.","Cd","Interaction")],col.line=c("blue", "red", "grey"),las=1,xlab="Speciation rate", legend="topright")
multi0mu<-data.frame(multi0postburn$mu0,multi0postburn$mud,multi0postburn$mucd)
colnames(multi0mu)<-c("Background","Cd","Interaction")
profiles.plot(multi0postburn["Background","Cd","Interaction"],col.line=c("blue", "red", "grey"),las=1,xlab="Extinction rate", legend="topright")
multi0cq<-data.frame(multi0postburn$qc01.0,multi0postburn$qc01.d,multi0postburn$qc10.0,multi0postburn$qc10.d)
colnames(multi0cq)<-c("Gain of conspic. -cd","Gain of conspic. +cd","Loss of conspic. -cd","Gain of conspic. +cd")
profiles.plot(multi0cq[c("Gain of conspic. -cd","Gain of conspic. +cd","Loss of conspic. -cd","Gain of conspic. +cd")],col.line=c("red", "blue", "grey", "yellow"),las=1,xlab="Transition rates (conspic.)", legend="topright")
multi0dq<-data.frame(multi0postburn$qd01.0,multi0postburn$qd01.c,multi0postburn$qd10.0,multi0postburn$qd10.c)
colnames(multi0dq)<-c("Gain of cd -conspic.","Gain of cd +conspic.","Loss of cd -conspic.","Loss of cd +conspic.")
profiles.plot(multi0cq[c("Gain of cd -conspic.","Gain of cd +conspic.","Loss of cd -conspic.","Loss of cd +conspic.")],col.line=c("red", "blue", "grey", "yellow"),las=1,xlab="Transition rates (cd)", legend="topright")
# Do I need net diversification? Still needs coded if so (as does the con1 dataset) 
con0postburn$netdiv0<-con0postburn$lambda0-con0postburn$mu0
con0postburn$netdiv1<-con0postburn$lambda1-con0postburn$mu0
con0div<-data.frame(con0postburn$netdiv0,con0postburn$netdiv1)
colnames(con0div)<-c("Cryptic","Conspic.")
profiles.plot(con0div[c("Cryptic","Conspic.")],col.line=c("blue", "red"),las=1,xlab="Net diversification rate (spec. - ex.)", legend="topright")

# MuSSE (multitrait) analysis of conspicuous coloration (con1) and chemical defence data with MCMC (sampling fraction as proportion of amphibian species present in the analysis, assuming 7869 currently known species)
library(diversitree)
c<-as.numeric(cddat$con1)-1
d<-as.numeric(cddat$cd)-1
musdat<-data.frame(c,d)
rownames(musdat)<-rownames(cddat)
lik<-make.musse.multitrait(cdtree,musdat,sampling.f=0.11)
# probably have to add in other constraints to reflect best model
start<-c(0.06118987,0.09847387,0.00000108594,0.0811571,0.003994628,0.004364655) # vector of ML estimates from best model
tmp<-mcmc(lik,start,nsteps=1000,w=0.1)
w<-diff(sapply(tmp[2:7],quantile,c(.05, .95))) # check column numbers from tmp
multi1mc<-mcmc(lik,start,nsteps=15000,w=w)
write.csv(multi1mc,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\multi1post.csv")
multi1postburn<-multi1mc[5001:15000,]
write.csv(multi1postburn,"I:\\PhD work\\Amphibian diversification study\\Analysis files\\multi1postburn.csv")

# Plotting parameter estimates for conspicuous coloration (con1) and chemical defence data from MCMC analysis of best ML model
# May need to adjust this to reflect the actual model to be plotted
library(diversitree)
par(mfrow=c(2,2))
con1lam<-data.frame(con1postburn$lambda0,con1postburn$lambda1)
colnames(con1lam)<-c("Cryptic","Conspic.")
profiles.plot(con1lam[c("Cryptic","Conspic.")],col.line=c("blue", "red"),las=1,xlab="Speciation rate", legend="topright")
con1mu<-data.frame(con1postburn$mu0,con1postburn$mu1)
colnames(con1mu)<-c("Cryptic","Conspic.")
profiles.plot(con1mu[c("Cryptic","Conspic.")],col.line=c("blue", "red"),las=1,xlab="Extinction rate", legend="topright")
con1q<-data.frame(con1postburn$q01,con1postburn$q10)
colnames(con1q)<-c("Gain of conspic.","Loss of conspic.")
profiles.plot(con1q[c("Gain of conspic.","Loss of conspic.")],col.line=c("red", "blue"),las=1,xlab="Transition rates", legend="topright")
con1postburn$netdiv0<-con1postburn$lambda0-con1postburn$mu0
con1postburn$netdiv1<-con1postburn$lambda1-con1postburn$mu1
con1div<-data.frame(con1postburn$netdiv0,con1postburn$netdiv1)
colnames(con1div)<-c("Cryptic","Conspic.")
profiles.plot(con1div[c("Cryptic","Conspic.")],col.line=c("blue", "red"),las=1,xlab="Net diversification rate (spec. - ex.)", legend=locator(1))
