# Open and check full tree
library(ape)
tree<-read.tree("F:\\PhD work\\Amphibian diversification study\\Analysis files\\amphibia.nwk")
summary(tree)
is.ultrametric(tree)

# View full tree
plot(tree,show.tip.label=F,no.margin=T,edge.color="dark blue")

# Read in datafiles (inc. check)
dat<-read.csv("F:\\PhD work\\Amphibian diversification study\\Analysis files\\totdat.csv",header=T,row.names=1)
dat$cd<-as.factor(dat$cd)
dat$con0<-as.factor(dat$con0)
dat$con1<-as.factor(dat$con1)
summary(dat)
dat[1:10,]

condat<-read.csv("F:\\PhD work\\Amphibian diversification study\\Analysis files\\condat.csv",header=T,row.names=1)
condat$cd<-as.factor(condat$cd)
condat$con0<-as.factor(condat$con0)
condat$con1<-as.factor(condat$con1)
summary(condat)
condat[1:10,]

# Open and check reduced tree
library(ape)
contree<-read.tree("F:\\PhD work\\Amphibian diversification study\\Analysis files\\contree.nwk")
summary(contree)
is.ultrametric(contree)

# View reduced tree
plot(contree,show.tip.label=F,no.margin=T,edge.color="dark blue")

# MuSSE analysis of conspicuous coloration data with ML (sampling fraction as observed in the dataset, assuming 7869 currently known species)
library(diversitree)
col<-as.numeric(condat$con)
names(col)<-rownames(condat)
lik<-make.musse(contree,col,k=4,sampling.f=0.33)
start<-starting.point.musse(contree,k=4)
fit<-find.mle(lik,start)
fit
logLik(fit)
AIC(fit)
lik.allcon<-constrain(lik,lambda2~lambda1,lambda3~lambda1,lambda4~lambda1,mu2~mu1,mu3~mu1,mu4~mu1,q13~q12,q14~q12,q21~q12,q23~q12,q24~q12,q31~q12,q32~q12,q34~q12,q41~q12,q42~q12,q43~q12)
fit.allcon<-find.mle(lik.allcon,start[c("lambda1","mu1","q12")])
fit.allcon
logLik(fit.allcon)
AIC(fit.allcon)
lik.divcon<-constrain(lik,lambda2~lambda1,lambda3~lambda1,lambda4~lambda1,mu2~mu1,mu3~mu1,mu4~mu1)
fit.divcon<-find.mle(lik.divcon,start[c("lambda1","mu1","q12","q13","q14","q21","q23","q24","q31","q32","q34","q41","q42","q43")])
fit.divcon
logLik(fit.divcon)
AIC(fit.divcon)
lik.spcon<-constrain(lik,lambda2~lambda1,lambda3~lambda1,lambda4~lambda1)
fit.spcon<-find.mle(lik.spcon,start[c("lambda1","mu1","mu2","mu3","mu4","q12","q13","q14","q21","q23","q24","q31","q32","q34","q41","q42","q43")])
fit.spcon
logLik(fit.spcon)
AIC(fit.spcon)
lik.excon<-constrain(lik,mu2~mu1,mu3~mu1,mu4~mu1)
fit.excon<-find.mle(lik.excon,start[c("lambda1","lambda2","lambda3","lambda4","mu1","q12","q13","q14","q21","q23","q24","q31","q32","q34","q41","q42","q43")])
fit.excon
logLik(fit.excon)
AIC(fit.excon)
aic<-c(AIC(fit),AIC(fit.allcon),AIC(fit.divcon),AIC(fit.spcon),AIC(fit.excon))
library(MuMIn)
delta<-aic-min(aic)
delta
w<-Weights(aic)
round(w,digits=3)
er<-w[5]/w
er

# MuSSE analysis of conspicuous coloration data with MCMC (sampling fraction as observed in the dataset, assuming 7869 currently known species. Starting parameters from best model in ML analysis)
library(diversitree)
col<-as.numeric(condat$con)
names(col)<-rownames(condat)
lik<-make.musse(contree,col,k=4,sampling.f=0.33)
start<-c(0.0146,0.0614,0.0535,0.1472,0.0000,0.0000,0.0027,0.0658,0.0055,0.0048,0.0001,0.0006,0.0015,0.0003,0.0036,0.0209,0.0059,0.0079,0.0150,0.0113)
tmp<-mcmc(lik,start,nsteps=1000,w=0.1)
w<-diff(sapply(tmp[2:21],quantile,c(.05, .95)))
conmc<-mcmc(lik,start,nsteps=15000,w=w)
write.csv(conmc,"F:\\PhD work\\Amphibian diversification study\\Analysis files\\mussecon\\conpost.csv")
conpostburn<-conmc[5001:15000,]
write.csv(conpostburn,"F:\\PhD work\\Amphibian diversification study\\Analysis files\\mussecon\\conpostburn.csv")

# Restarting a partially completed analysis
reconmc<-mcmc(lik,x.init=NULL,nsteps=15000,w=w,previous=conmc)
conmc<-reconmc

# Plotting parameter estimates for conspicuous coloration data from MCMC analysis of best ML MuSSE model
library(diversitree)
par(mfrow=c(1,2))
conlam<-data.frame(conpostburn$lambda1,conpostburn$lambda2,conpostburn$lambda3,conpostburn$lambda4)
colnames(conlam)<-c("Uncertain","Cryptic","Polymorphic","Conspic.")
profiles.plot(conlam[c("Uncertain","Cryptic","Polymorphic","Conspic.")],col.line=c("grey","blue","yellow","red"),las=1,xlab="Speciation rate", legend="topright")
conmu<-data.frame(conpostburn$mu1,conpostburn$mu2,conpostburn$mu3,conpostburn$mu4)
colnames(conmu)<-c("Uncertain","Cryptic","Polymorphic","Conspic.")
profiles.plot(conmu[c("Uncertain","Cryptic","Polymorphic","Conspic.")],col.line=c("grey","blue","yellow","red"),las=1,xlab="Extinction rate", legend="topright")
conq<-data.frame(conpostburn$q12,conpostburn$q13,conpostburn$q14,conpostburn$q21,conpostburn$q23,conpostburn$q24,conpostburn$q31,conpostburn$q32,conpostburn$q34,conpostburn$q41,conpostburn$q42,conpostburn$q43)
colnames(conq)<-c("Uncertain-cryptic","Uncertain-polymorphic","Uncertain-conspic.","Cryptic-uncertain","Cryptic-polymorphic","Cryptic-conspic.","Polymorphic-uncertain","Polymorphic-cryptic","Polymorphic-conspicuous","Conspic.-uncertain","Conspic.-cryptic","Conspic.-polymorphic")
windows()
library(RColorBrewer)
pal<-brewer.pal(12,"Paired")
profiles.plot(conq[c("Uncertain-cryptic","Uncertain-polymorphic","Uncertain-conspic.","Cryptic-uncertain","Cryptic-polymorphic","Cryptic-conspic.","Polymorphic-uncertain","Polymorphic-cryptic","Polymorphic-conspicuous","Conspic.-uncertain","Conspic.-cryptic","Conspic.-polymorphic")],col.line=pal,las=1,xlab="Transition rates", legend="topright")
conpostburn$netdiv1<-conpostburn$lambda1-conpostburn$mu1
conpostburn$netdiv2<-conpostburn$lambda2-conpostburn$mu2
conpostburn$netdiv3<-conpostburn$lambda3-conpostburn$mu3
conpostburn$netdiv4<-conpostburn$lambda4-conpostburn$mu4
condiv<-data.frame(conpostburn$netdiv1,conpostburn$netdiv2,conpostburn$netdiv3,conpostburn$netdiv4)
colnames(condiv)<-c("Uncertain","Cryptic","Polymorphic","Conspic.")
windows()
profiles.plot(condiv[c("Uncertain","Cryptic","Polymorphic","Conspic.")],col.line=c("grey","blue","yellow","red"),las=1,xlab="Net diversification rate (spec. - ex.)", legend="topright")

